@@ -2,11 +2,10 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 
-"""calculate_kpi.py
-This module contains the CRON job that is periodically executed to calculate key
-performance indicators (KPIs) and save them to the database.
-This code assumes prognoses are available from the persistent storage. If these are not
-available run create_forecast.py to train all models.
+"""This module contains the CRON job that is periodically executed to calculate key performance indicators (KPIs).
+
+This code assumes prognoses are available from the persistent storage.
+If these are not available run create_forecast.py to train all models.
 
 The folowing tasks are caried out:
   1: Calculate the KPI for a given pid. Ignore SplitEnergy
@@ -17,7 +16,7 @@ Example:
     This module is meant to be called directly from a CRON job.
     Alternatively this code can be run directly by running::
         $ python calculate_kpi.py
-Attributes:
+
 """
 # Import builtins
 from datetime import datetime, timedelta
@@ -27,8 +26,8 @@ import numpy as np
 import pandas as pd
 import structlog
 
-from openstef.enums import MLModelType
 from openstef.data_classes.prediction_job import PredictionJobDataClass
+from openstef.enums import MLModelType
 from openstef.exceptions import NoPredictedLoadError, NoRealisedLoadError
 from openstef.metrics import metrics
 from openstef.tasks.utils.predictionjobloop import PredictionJobLoop
@@ -45,7 +44,8 @@ def main(model_type: MLModelType = None, config=None, database=None) -> None:
 
     if database is None or config is None:
         raise RuntimeError(
-            "Please specifiy a configmanager and/or database connection object. These can be found in the openstef-dbc package."
+            "Please specifiy a configmanager and/or database connection object. These"
+            " can be found in the openstef-dbc package."
         )
 
     if model_type is None:
@@ -85,9 +85,13 @@ def check_kpi_task(
     )
 
     # Get basecase prediction
-    basecase = context.database.get_load_pid(
+    load_1_week_before = context.database.get_load_pid(
         pj["id"], start_time - timedelta(days=7), end_time - timedelta(days=7), "15T"
-    ).shift(periods=7, freq="d")
+    )
+    if len(load_1_week_before) > 0:
+        basecase = load_1_week_before.shift(periods=7, freq="d")
+    else:
+        basecase = pd.DataFrame()
 
     kpis = calc_kpi_for_specific_pid(pj["id"], realised, predicted_load, basecase)
     # Write KPI's to database
@@ -125,7 +129,8 @@ def calc_kpi_for_specific_pid(
     predicted_load: pd.DataFrame,
     basecase: pd.DataFrame,
 ) -> dict:
-    """Function that checks the model performance based on a pid. This function
+    """Function that checks the model performance based on a pid. This function.
+
     - loads and combines forecast and realised data
     - calculated several key performance indicators (KPIs)
     These metric include:
@@ -135,13 +140,14 @@ def calc_kpi_for_specific_pid(
         - Mean absolute Error
 
     Args:
-        pj (PredictionJobDataclass): Prediction ID for a given prediction job
-        start_time (datetime): Start time from when to retrieve the historic load prediction.
-        end_time (datetime): Start time till when to retrieve the historic load prediction.
+        pid: Prediction ID for a given prediction job
+        realised: Realised load.
+        predicted_load: Predicted load.
+        basecase: Basecase predicted load.
 
     Returns:
-        Dictionary that includes a dictonary for each t_ahead.
-        Dict includes enddate en window (in days) for clarification
+        - Dictionary that includes a dictonary for each t_ahead.
+        - Dict includes enddate en window (in days) for clarification
 
     Raises:
         NoPredictedLoadError: When no predicted load for given datatime range.
@@ -149,6 +155,7 @@ def calc_kpi_for_specific_pid(
 
     Example:
         To get the rMAE for the 24 hours ahead prediction: kpis['24h']['rMAE']
+
     """
     COMPLETENESS_REALISED_THRESHOLDS = 0.7
     COMPLETENESS_PREDICTED_LOAD_THRESHOLD = 0.7
@@ -177,8 +184,10 @@ def calc_kpi_for_specific_pid(
     # Combine the forecast and the realised to make sure indices are matched nicely
     combined = pd.merge(realised, predicted_load, left_index=True, right_index=True)
 
-    # TODO: make basecase calculation optional only if there was data available 7 days before
     # Add basecase (load in same time period 7 days ago)
+    # Check if basecase is not empty, else make a dummy dataframe
+    if len(basecase) == 0:
+        basecase = pd.DataFrame(columns=["load"])
     basecase = basecase.rename(columns=dict(load="basecase"))
 
     combined = combined.merge(basecase, how="left", left_index=True, right_index=True)
@@ -186,7 +195,8 @@ def calc_kpi_for_specific_pid(
     # Raise exception in case of constant load
     if combined.load.nunique() == 1:
         structlog.get_logger(__name__).warning(
-            "The load is constant! KPIs will still be calculated, but relative metrics will be nan"
+            "The load is constant! KPIs will still be calculated, but relative metrics"
+            " will be nan"
         )
 
     # Define output dictonary
@@ -290,12 +300,12 @@ def calc_kpi_for_specific_pid(
 
 
 def set_incomplete_kpi_to_nan(kpis: dict, t_ahead_h: str) -> None:
-    """
-    Checks the given kpis for completeness and sets to nan if this not true
+    """Checks the given kpis for completeness and sets to nan if this not true.
+
+    Args:
+        kpis: the kpis
+        t_ahead_h: t_ahead_h
 
-    :param kpis: the kpis
-    :param t_ahead_h: t_ahead_h
-    :return: -
     """
     kpi_metrics = list(kpis[t_ahead_h].keys())
     # Set to nan
