@@ -1,12 +1,8 @@
 # SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
+"""This module contains the CRON job that is periodically executed to make prognoses and save them in to the database.
 
-# -*- coding: utf-8 -*-
-"""create_forecast.py
-
-This module contains the CRON job that is periodically executed to make prognoses and
-save them in to the database.
 This code assumes trained models are available from the persistent storage. If these
 are not available run model_train.py to train all models.
 To provide the prognoses the folowing steps are carried out:
@@ -23,9 +19,6 @@ Example:
 
         $ python create_forecast.py
 
-Attributes:
-
-
 """
 from datetime import datetime, timedelta
 from pathlib import Path
@@ -45,12 +38,13 @@ def create_forecast_task(pj: PredictionJobDataClass, context: TaskContext) -> No
 
     On this task level all database and context manager dependencies are resolved.
 
-    Expected prediction job keys: "id", "lat", "lon", "resolution_minutes",
+    Expected prediction job keys; "id", "lat", "lon", "resolution_minutes",
         "horizon_minutes", "type", "name", "quantiles"
 
     Args:
-        pj (PredictionJobDataClass): Prediction job
-        context (TaskContext): Contect object that holds a config manager and a database connection
+        pj: Prediction job
+        context: Contect object that holds a config manager and a database connection
+
     """
     # Extract mlflow tracking URI and trained models folder
     mlflow_tracking_uri = context.config.paths.mlflow_tracking_uri
@@ -76,7 +70,6 @@ def create_forecast_task(pj: PredictionJobDataClass, context: TaskContext) -> No
 
 
 def main(model_type=None, config=None, database=None):
-
     taskname = Path(__file__).name.replace(".py", "")
 
     if database is None or config is None:
