@@ -1,17 +1,15 @@
 # SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
+"""This module contains the CRON job that is periodically executed to make prognoses of solar features.
+
+These are useful for splitting the load in solar and wind contributions.
 
-"""create_solar_forecast
-This module contains the CRON job that is periodically executed to make
-prognoses of solar features that are useful for splitting the load in solar and
-wind contributions.
 Example:
     This module is meant to be called directly from a CRON job. A description of
     the CRON job can be found in the /k8s/CronJobs folder.
     Alternatively this code can be run directly by running::
         $ python create_solar_forecast
-Attributes:
 
 """
 from datetime import datetime, timedelta
@@ -34,6 +32,10 @@ def make_solar_prediction_pj(pj, context, radius=30, peak_power=180961000.0):
 
     Args:
         pj: (dict) prediction job
+        context: Task context
+        radius: Radius us to collect PV systems.
+        peak_power: Peak power.
+
     """
     context.logger.info("Get solar input data from database")
     # pvdata is only stored in the prd database
@@ -68,16 +70,16 @@ def make_solar_prediction_pj(pj, context, radius=30, peak_power=180961000.0):
 
 
 def combine_forecasts(forecasts, combination_coefs):
-    """This function combines several independent forecasts into one, using
-        predetermined coefficients.
+    """This function combines several independent forecasts into one, using predetermined coefficients.
 
     Input:
         - forecasts: pd.DataFrame(index = datetime, algorithm1, ..., algorithmn)
         - combinationcoefs: pd.DataFrame(param1, ..., paramn, algorithm1, ..., algorithmn)
 
     Output:
-        - pd.DataFrame(datetime, forecast)"""
+        - pd.DataFrame(datetime, forecast)
 
+    """
     models = [x for x in list(forecasts) if x not in ["created", "datetime"]]
 
     # Add subset parameters to df
@@ -171,22 +173,22 @@ def combine_forecasts(forecasts, combination_coefs):
     return result_df
 
 
-def fides(data, all_forecasts=False):
+def fides(data: pd.DataFrame, all_forecasts: bool = False):
     """Fides makes a forecast based on persistence and a direct fit with insolation.
 
     Args:
         data: pd.DataFrame(index = datetime, columns =['output','insolation'])
-        allForecasts (bool): Should all forecasts be returned or only the combination
+        all_forecasts: Should all forecasts be returned or only the combination
 
     Example:
-
     import numpy as np
     index = pd.date_range(start = "2017-01-01 09:00:00", freq = '15T', periods = 300)
     data = pd.DataFrame(index = index,
                         data = dict(load=np.sin(index.hour/24*np.pi)*np.random.uniform(0.7,1.7, 300)))
     data['insolation'] = data.load * np.random.uniform(0.8, 1.2, len(index)) + 0.1
-    data.loc[int(len(index)/3*2):,"load"] = np.NaN"""
+    data.loc[int(len(index)/3*2):,"load"] = np.NaN
 
+    """
     insolation_forecast = apply_fit_insol(data, add_to_df=False)
     persistence = apply_persistence(data, how="mean", smooth_entries=4, add_to_df=True)
 
@@ -249,6 +251,7 @@ def main(config=None, database=None):
 
 def calc_norm(data, how="max", add_to_df=True):
     """This script calculates the norm of a given dataset.
+
     Input:
         - data: pd.DataFrame(index = datetime, columns = [load])
         - how: str can be any function from numpy, recognized by np.'how'
@@ -259,13 +262,14 @@ def calc_norm(data, how="max", add_to_df=True):
         - pd.DataFrame(index = datetime, columns = [load])
     NB: range of datetime of input is equal to range of datetime of output
 
-    Example
+    Example:
     import pandas as pd
     import numpy as np
     index = pd.date_range(start = "2017-01-01 09:00:00", freq = '15T', periods = 200)
     data = pd.DataFrame(index = index,
-                        data = dict(load=np.sin(index.hour/24*np.pi)*np.random.uniform(0.7,1.7, 200)))"""
+                        data = dict(load=np.sin(index.hour/24*np.pi)*np.random.uniform(0.7,1.7, 200)))
 
+    """
     colname = list(data)[0]
     if how == "max":
         df = data.groupby(data.index.time).apply(lambda x: x.max(skipna=True))
@@ -285,7 +289,8 @@ def calc_norm(data, how="max", add_to_df=True):
 
 
 def apply_persistence(data, how="mean", smooth_entries=4, add_to_df=True, colname=None):
-    """This script calculates the persistence forecast
+    """This script calculates the persistence forecast.
+
     Input:
         - data: pd.DataFrame(index = datetime, columns = [load]), datetime is expected to have historic values, as well as NA values
         Optional:
@@ -298,14 +303,15 @@ def apply_persistence(data, how="mean", smooth_entries=4, add_to_df=True, colnam
         - pd.DataFrame(index = datetime, columns = [(load,) persistence])
     NB: range of datetime of input is equal to range of datetime of output
 
-    Example
+    Example:
     import pandas as pd
     import numpy as np
     index = pd.date_range(start = "2017-01-01 09:00:00", freq = '15T', periods = 300)
     data = pd.DataFrame(index = index,
                         data = dict(load=np.sin(index.hour/24*np.pi)*np.random.uniform(0.7,1.7, 300)))
-    data.loc[200:,"load"] = np.nan"""
+    data.loc[200:,"load"] = np.nan
 
+    """
     data = data.sort_index()
 
     if colname is None:
@@ -332,8 +338,7 @@ def apply_persistence(data, how="mean", smooth_entries=4, add_to_df=True, colnam
 
 
 def apply_fit_insol(data, add_to_df=True, hours_delta=None, polynomial=False):
-    """This model fits insolation to PV yield and uses this fit to forecast PV yield.
-    It uses a 2nd order polynomial
+    """This model fits insolation to PV yield and uses this fit to forecast PV yield. It uses a 2nd order polynomial.
 
     Input:
         - data: pd.DataFrame(index = datetime, columns = [load, insolation])
@@ -345,15 +350,16 @@ def apply_fit_insol(data, add_to_df=True, hours_delta=None, polynomial=False):
         - pd.DataFrame(index = datetime, columns = [(load), forecaopenstefitInsol])
     NB: range of datetime of input is equal to range of datetime of output
 
-    Example
+    Example:
     import pandas as pd
     import numpy as np
     index = pd.date_range(start = "2017-01-01 09:00:00", freq = '15T', periods = 300)
     data = pd.DataFrame(index = index,
                         data = dict(load=np.sin(index.hour/24*np.pi)*np.random.uniform(0.7,1.7, len(index))))
     data['insolation'] = data.load * np.random.uniform(0.8, 1.2, len(index)) + 0.1
-    data.loc[int(len(index)/3*2):,"load"] = np.NaN"""
+    data.loc[int(len(index)/3*2):,"load"] = np.NaN
 
+    """
     colname = list(data)[0]
 
     # Define subset, only keep non-NaN values and the most recent forecasts
